import 'package:flutter/material.dart';
import 'package:flutter_clx_base/common/gaps.dart';
import 'package:flutter_clx_base/utils/keyboard_utils.dart';
import 'package:flutter_clx_base/utils/string_util.dart';
import 'package:flutter_clx_base/utils/toast_util.dart';
import 'package:get/get.dart';
import 'package:keyboard_actions/keyboard_actions.dart';

class SearchAppBar extends StatefulWidget implements PreferredSizeWidget {
  final Function? onCallback;
  final String? hintText;
  final bool showLeading;
  final Color backgroundColor;
  final bool primary;

  const SearchAppBar({
    Key? key,
    this.onCallback,
    this.hintText = "请输入搜索内容",
    this.showLeading = true,
    this.backgroundColor = Colors.blue,
    this.primary = true,
  }) : super(key: key);

  @override
  State<SearchAppBar> createState() => _SearchAppBarState();

  @override
  Size get preferredSize => const Size(double.infinity, 55.0);
}

class _SearchAppBarState extends State<SearchAppBar> {
  final searchInfoController = TextEditingController();
  final searchFocusNode = FocusNode();

  @override
  Widget build(BuildContext context) {
    return KeyboardActions(
      config:
          KeyBoardUtils.getKeyboardActionsConfig(context, [searchFocusNode]),
      tapOutsideBehavior: TapOutsideBehavior.opaqueDismiss,
      child: AppBar(
        backgroundColor: widget.backgroundColor,
        titleSpacing: 0.0,
        primary: widget.primary,
        leading: widget.showLeading
            ? InkWell(
                onTap: () => Get.back(),
                child: const Icon(Icons.arrow_back_ios, color: Colors.white),
              )
            : Container(),
        leadingWidth: widget.showLeading ? null : 0.0,
        title: Container(
          color: Colors.blue,
          child: Row(
            children: <Widget>[
              Expanded(
                child: Container(
                  decoration: const BoxDecoration(
                    borderRadius: BorderRadius.all(Radius.circular(20.0)),
                    color: Color(0xFFEEEEEE),
                  ),
                  child: Row(
                    children: <Widget>[
                      hGap10,
                      Icon(Icons.search, color: Colors.grey.shade300),
                      hGap5,
                      Expanded(
                        child: TextField(
                          maxLines: 1,
                          focusNode: searchFocusNode,
                          style: const TextStyle(fontSize: 14),
                          textInputAction: TextInputAction.search,
                          controller: searchInfoController,
                          onSubmitted: (value) => _search(),
                          decoration: InputDecoration(
                            contentPadding: const EdgeInsets.symmetric(
                                horizontal: 0.0, vertical: 8.0),
                            isDense: true,
                            counterText: "",
                            hintText: widget.hintText,
                            hintStyle: const TextStyle(
                                fontSize: 14.0, color: Color(0xFF999999)),
                            border: InputBorder.none, //去掉下划线
                            //hintStyle: TextStyles.textGrayC14
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              InkWell(
                onTap: () => _search(),
                child: Container(
                  width: 60.0,
                  alignment: Alignment.center,
                  child: const Text(
                    "搜索",
                    style: TextStyle(color: Color(0xFFFFFFFF), fontSize: 14.0),
                  ),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }

  /// 校验
  bool _checkInfo() {
    if (isNullOrEmpty(getControllerString(searchInfoController))) {
      ToastUtil.showToast("请输入搜索内容");
      return false;
    }
    return true;
  }

  /// 搜索
  void _search() {
    if (_checkInfo()) {
      KeyBoardUtils.hideKeyboard();
      if (widget.onCallback != null) {
        widget.onCallback!(getControllerString(searchInfoController));
      }
    }
  }
}
